from celery.result import states
from django.utils.safestring import mark_safe

from gisdo import settings as gs_settings
from kinder.core.async_tasks.tasks import AsyncTask
from kinder.core.unit.models import Unit

from .service import IndexReportService


class UnloadChildrenByIndexTask(AsyncTask):
    """Задача отчета "Выгрузка детей по показателю/тегу ФО"."""

    description = 'Выгрузка детей по показателю/тегу ФО.'
    queue = gs_settings.CELERY_WORKER_TASK_QUEUE

    def run(self, **kwargs):
        super().run(**kwargs)

        unit_id = kwargs.get('unit_id')
        indexes = kwargs.get('indexes', [])

        self.set_progress(
            'Подсчет показателей...', task_state='RUNNING')

        unit = Unit.objects.get(id=unit_id)

        result_name = IndexReportService(
            unit, indexes, self.set_progress).collect_and_build()

        url = f'{gs_settings.DOWNLOADS_URL}/{result_name}.xlsx'
        self.set_progress(
            mark_safe(
                f'<a href="{url}" target="_blank">Отчет сформирован</a>'
            ),
            task_state=states.SUCCESS
        )

        return self._result_message(
            'Формирование завершено', state=states.SUCCESS)
